from unittest.mock import Mock, patch

import toddlers.utils.notify


class TestNotify:
    @patch("toddlers.utils.notify.smtplib")
    def test_notify_packager(self, mock_smtp):
        smtp_server = Mock()
        mock_smtp.SMTP.return_value = smtp_server

        msg = """To: pingou@email
From: admin@server
Subject: Fedora Account System and Bugzilla Mismatch

Hello pingou,

We have identified you[1] as either a Fedora packager or someone who has asked to
be included in the CC list of tickets created for one or more component on
bugzilla. Fedora packagers are granted special permissions on the Fedora bugs in
bugzilla.
However, to enable these functionalities (granting you these permissions or
including you to the CC list of your packages of interest), we need to have your
bugzilla email address stored in the Fedora Account System[2].
At the moment you have:

pingou@email

which bugzilla is telling us is not an account in bugzilla.  If you could
please set up an account in bugzilla with this address or change your email
address on your Fedora Account to match an existing bugzilla account this would
let us go forward.

Note: this message is being generated by an automated script.  You'll continue
getting this message until the problem is resolved.  Sorry for the
inconvenience.

Thank you,
The Fedora Account System
admin@server


[1] the source of this information is the following JSON file:
    https://src.fedoraproject.org/extras/pagure_bz.json
    We are happy to tell you exactly which packages are linked to your account
    if you wish.
[2] https://admin.fedoraproject.org/accounts
"""

        toddlers.utils.notify.notify_packager(
            mail_server="server.mail",
            admin_email="admin@server",
            username="pingou",
            email="pingou@email",
        )
        mock_smtp.SMTP.assert_called_with("server.mail")
        smtp_server.sendmail.assert_called_with("admin@server", ["pingou@email"], msg)

    @patch("toddlers.utils.notify.smtplib")
    def test_notify_admins(self, mock_smtp):
        users = []
        for name, email in [
            ("pingou", "pingou@mail"),
            ("nils", "nils@mail"),
            ("trasher", "trasher@mail"),
        ]:
            user = Mock()
            if name == "trasher":
                user.person.status = "Inactive"
            else:
                user.person.status = "Active"
            user.person.username = name
            user.person.human_name = name
            user.email = email
            users.append(user)

        smtp_server = Mock()
        mock_smtp.SMTP.return_value = smtp_server

        msg = """To: info_admin@server
From: admin@server
Subject: Fedora Account System and Bugzilla Mismatch


The following people are in the packager group but do not have email addresses
that are valid in bugzilla:
  pingou  --  pingou  --  pingou@mail
  nils  --  nils  --  nils@mail

"""

        toddlers.utils.notify.notify_admins(
            mail_server="server.mail",
            admin_email="admin@server",
            recipients=["info_admin@server"],
            users=users,
        )
        mock_smtp.SMTP.assert_called_with("server.mail")
        smtp_server.sendmail.assert_called_with(
            "admin@server", ["info_admin@server"], msg
        )
