import abc


class ToddlerBase(object):
    __metaclass__ = abc.ABCMeta

    @property
    @abc.abstractmethod
    def name(self):
        """Returns name of the plugin."""
        return "base"

    @property
    @abc.abstractmethod
    def amqp_topics(self):
        """Returns the list of topics of interest for this toddler in a format
        that can be used directly when connecting to amqp.
        For example, it supports items like:
            ``org.fedoraproject.#.buildsys.build.state.change``
        which is valid when subscribing to a queue in amqp but will not allow
        string based comparison with the topic extracted from the message.

        """
        return []

    @abc.abstractmethod
    def accepts_topic(self, topic):
        """Returns a boolean whether this toddler is interested in messages
        from this specific topic.
        """
        return

    @abc.abstractmethod
    def process(self, config, message):
        """Process a given message."""
        return
