from email.message import EmailMessage
import smtplib


def notify_packager(mail_server, admin_email, username, email):

    msg = EmailMessage()
    message = f"""Hello {username},

We have identified you[1] as either a Fedora packager or someone who has asked to
be included in the CC list of tickets created for one or more component on
bugzilla. Fedora packagers are granted special permissions on the Fedora bugs in
bugzilla.
However, to enable these functionalities (granting you these permissions or
including you to the CC list of your packages of interest), we need to have your
bugzilla email address stored in the Fedora Account System[2].
At the moment you have:

{email}

which bugzilla is telling us is not an account in bugzilla.  If you could
please set up an account in bugzilla with this address or change your email
address on your Fedora Account to match an existing bugzilla account this would
let us go forward.

Note: this message is being generated by an automated script.  You'll continue
getting this message until the problem is resolved.  Sorry for the
inconvenience.

Thank you,
The Fedora Account System
{admin_email}


[1] the source of this information is the following JSON file:
    https://src.fedoraproject.org/extras/pagure_bz.json
    We are happy to tell you exactly which packages are linked to your account
    if you wish.
[2] https://admin.fedoraproject.org/accounts
"""

    msg.add_header("To", email)
    msg.add_header("From", admin_email)
    msg.add_header("Subject", "Fedora Account System and Bugzilla Mismatch")
    msg.set_payload(message)
    smtp = smtplib.SMTP(mail_server)
    smtp.sendmail(admin_email, [email], msg.as_string())
    smtp.quit()


def notify_admins(mail_server, admin_email, recipients, users):

    msg = EmailMessage()
    people = []
    for person in users:
        if person.person.status == "Active":
            people.append(
                "  %(user)s  --  %(name)s  --  %(email)s"
                % {
                    "name": person.person.human_name,
                    "email": person.email,
                    "user": person.person.username,
                }
            )
    if people:
        people = "\n".join(people)
        message = (
            """
The following people are in the packager group but do not have email addresses
that are valid in bugzilla:
%s

"""
            % people
        )

    msg.add_header("To", ", ".join(recipients))
    msg.add_header("From", admin_email)
    msg.add_header("Subject", "Fedora Account System and Bugzilla Mismatch")
    msg.set_payload(message)
    smtp = smtplib.SMTP(mail_server)
    smtp.sendmail(admin_email, recipients, msg.as_string())
    smtp.quit()
